<html>
<head>
    <title>Editor Grids</title>
    <link rel="stylesheet" type="text/css" href="../lib/extjs/resources/css/ext-all.css" />
    <script type="text/javascript" src="../lib/extjs/adapter/ext/ext-base.js"></script>
    <script type="text/javascript" src="../lib/extjs/ext-all.js"></script>
    <script>
    Ext.onReady(function(){
        Ext.BLANK_IMAGE_URL = 'images/s.gif';
        Ext.QuickTips.init();

        Ext.form.VTypes.nameVal  = /^[A-Z][A-Za-z]+\s[A-Z][A-Za-z]+$/;
        Ext.form.VTypes.nameMask = /[A-Za-z ]/;
        Ext.form.VTypes.nameText = 'Invalid Director Name.';
        Ext.form.VTypes.name     = function(v){
            return Ext.form.VTypes.nameVal.test(v);
        };

        var genres = new Ext.data.SimpleStore({
            fields: ['id', 'genre'],
            data : [['0','New Genre'],['1','Comedy'],['2','Drama'],['3','Action']]
        });

        function genre_name(val){
            return genres.queryBy(function(rec){
                return rec.data.id == val;
            }).itemAt(0).data.genre;
        }

        var Movie = Ext.data.Record.create([
            'id',
            'coverthumb',
            'title',
            'director',
            {name: 'runtime', type: 'int'},
            {name: 'released', type: 'date', dateFormat: 'Y-m-d'},
            'genre',
            'tagline',
            {name: 'price', type: 'float'},
            {name: 'available', type: 'bool'}
        ]);

        var store = new Ext.data.Store({
            url: 'movies.php',
            reader: new Ext.data.JsonReader({
                root:'rows',
                totalProperty: 'results',
                id:'id'
            }, Movie),
            autoLoad: true
        });

        var title_edit = new Ext.form.TextField({
            allowBlank: false,
            maxLength: 45
        });

        var director_edit = new Ext.form.TextField({
            allowBlank: false,
            maxLength: 45,
            vtype: 'name'
        });

        var genre_edit = new Ext.form.ComboBox({
            typeAhead: true,
            forceSelection: true,
            triggerAction: 'all',
            mode: 'local',
            store: genres,
            displayField:'genre',
            valueField: 'id',
            listeners: {
                select: function(field, rec, idx){
                    if (i === 0){
                        Ext.Msg.prompt('New Genre','Name',Ext.emptyFn);
                    }
                }
            }
        });

        var runtime_edit = new Ext.form.NumberField({
            allowNegative: false,
            allowDecimals: false
        });

        release_edit = new Ext.form.DateField({
            format: 'm/d/Y',
            allowBlank: false
        });

        var tagline_edit = new Ext.form.TextField({
            allowBlank: false,
            maxLength: 45
        });

        var grid = new Ext.grid.EditorGridPanel({
            renderTo: document.body,
            frame: true,
            title: 'Movie Database',
            height: 300,
            width: 620,
            enableColumnMove: false,
            store: store,
            clicksToEdit: 2,
            columns: [
                {header: "Title", dataIndex: 'title', editor: title_edit},
                {header: "Director", dataIndex: 'director', editor: director_edit},
                {header: "Runtime", dataIndex: 'runtime', xtype: 'numbercolumn', format: '0', width: 70, editor: runtime_edit, align: 'right'},
                {header: "Released", dataIndex: 'released', xtype: 'datecolumn', format: 'M d Y', width: 80, editor: release_edit},
                {header: "Genre", dataIndex: 'genre', renderer: genre_name, editor: genre_edit},
                {header: "Tagline", dataIndex: 'tagline', editor: tagline_edit, width: 150}
            ],
            sm: new Ext.grid.RowSelectionModel({
                singleSelect: true
            }),
            listeners: {
                afteredit: function(e){
                    Ext.Ajax.request({
                        url: 'movies-update.php',
                        params: {
                            action: 'update',
                            id: e.record.id,
                            field: e.field,
                            value: e.value
                        },
                        success: function(resp,opt) {
                            e.record.commit();
                        },
                        failure: function(resp,opt) {
                            e.record.reject();
                        }
                    });
                }
            },
            keys: [{
                key: 46,
                fn: function(key,e){
                    var sm = grid.getSelectionModel(),
                        sel = sm.getSelected();
                    if (sm.hasSelection()){
                        Ext.Msg.show({
                            title: 'Remove Movie', 
                            buttons: Ext.MessageBox.YESNOCANCEL,
                            msg: 'Remove ' + sel.data.title + '?',
                            fn: function(btn){
                                if (btn == 'yes'){
                                    Ext.Ajax.request({
                                        url: 'movies-update.php',
                                        params: {
                                            action: 'destroy',
                                            id: sel.data.id
                                        },
                                        success: function(resp,opt) { 
                                            grid.getStore().remove(sel); 
                                        },
                                        failure: function(resp,opt) { 
                                            Ext.Msg.alert('Error','Unable to delete movie'); 
                                        }
                                    });
                                }
                            }
                        });
                    }
                },
                ctrl: false,
                stopEvent: true
            }],
            tbar: [{
                text: 'Add Movie',
                icon: 'images/table_add.png',
                cls: 'x-btn-text-icon',
                handler: function() {
                    Ext.Ajax.request({
                        url: 'movies-update.php',
                        params: {
                            action: 'create',
                            title: 'New Movie'
                        },
                        success: function(resp,opt) {
                            var insert_id = Ext.util.JSON.decode(
                                resp.responseText
                            ).insert_id;
                            grid.getStore().insert(0, new Movie({
                                id: insert_id,
                                title: 'New Movie',
                                director: '',
                                runtime: 0,
                                genre: 0,
                                tagline: ''
                            }, insert_id));
                            grid.startEditing(0,0);
                        },
                        failure: function(resp,opt) {
                            Ext.Msg.alert('Error','Unable to add movie');
                        }
                    });
                }
            },{
                text: 'Remove Movie',
                icon: 'images/table_delete.png',
                cls: 'x-btn-text-icon',
                handler: function() {
                    var sm = grid.getSelectionModel(),
                        sel = sm.getSelected();
                    if (sm.hasSelection()){
                        Ext.Msg.show({
                            title: 'Remove Movie', 
                            buttons: Ext.MessageBox.YESNOCANCEL,
                            msg: 'Remove ' + sel.data.title + '?',
                            fn: function(btn){
                                if (btn == 'yes'){
                                    Ext.Ajax.request({
                                        url: 'movies-update.php',
                                        params: {
                                            action: 'destroy',
                                            id: sel.data.id
                                        },
                                        success: function(resp,opt) { 
                                            grid.getStore().remove(sel); 
                                        },
                                        failure: function(resp,opt) { 
                                            Ext.Msg.alert('Error','Unable to delete movie'); 
                                        }
                                    });
                                }
                            }
                        });
                    }
                }
            }]
        });
    });
    </script>
</head>
<body>
</body>
</html>